@@ -12,7 +12,7 @@ use File::Spec::Functions qw(catfile catdir splitdir);
 use vars qw($VERSION @Pagers $Bindir $Pod2man
   $Temp_Files_Created $Temp_File_Lifetime
 );
-$VERSION = '3.27_02';
+$VERSION = '3.28_01';
 
 #..........................................................................
 
@@ -345,7 +345,7 @@ sub program_name {
     \A
     perl
       (?: doc | func | faq | help | op | toc | var # Camel 3
-      ) 
+      )
     (?: -? v? \d+ \. \d+ (?:\. \d+)? )? # possible version
     (?: \. (?: bat | exe | com ) )?    # possible extension
     \z
@@ -486,7 +486,7 @@ sub init_formatter_class_list {
 
   $self->opt_M_with('Pod::Perldoc::ToPod');   # the always-there fallthru
   $self->opt_o_with('text');
-  $self->opt_o_with('term') 
+  $self->opt_o_with('term')
     unless $self->is_mswin32 || $self->is_dos || $self->is_amigaos
        || !($ENV{TERM} && (
               ($ENV{TERM} || '') !~ /dumb|emacs|none|unknown/i
@@ -851,8 +851,11 @@ sub grand_search_init {
                    =~ s/\.P(?:[ML]|OD)\z//;
             }
             else {
-                print STDERR "No " .
+              print STDERR "No " .
                     ($self->opt_m ? "module" : "documentation") . " found for \"$_\".\n";
+              if ( /^https/ ) {
+                print STDERR "You may need an SSL library (such as IO::Socket::SSL) for that URL.\n";
+              }
             }
             next;
         }
@@ -1109,7 +1112,7 @@ sub search_perlvar {
     my $found = 0;
     my $inheader = 1;
     my $inlist = 0;
-    while (<$fh>) {  
+    while (<$fh>) {
         last if /^=head2 Error Indicators/;
         # \b at the end of $` and friends borks things!
         if ( m/^=item\s+$search_re\s/ )  {
@@ -1178,8 +1181,8 @@ sub search_perlop {
     next if $skip;
 
     # strategy is to capture the previous line until we get a match on X<$thingy>
-    # if the current line contains X<$thingy>, then we push "=over", the previous line, 
-    # the current line and keep pushing current line until we see a ^X<some-other-thing>, 
+    # if the current line contains X<$thingy>, then we push "=over", the previous line,
+    # the current line and keep pushing current line until we see a ^X<some-other-thing>,
     # then we chop off final line from @$pod and add =back
     #
     # At that point, Bob's your uncle.
@@ -1670,9 +1673,9 @@ sub pagers_guessing {
         push @pagers, qw( less.exe more.com< );
         unshift @pagers, $ENV{PAGER}  if $ENV{PAGER};
     }
-    elsif ( $self->is_amigaos) { 
+    elsif ( $self->is_amigaos) {
       push @pagers, qw( /SYS/Utilities/MultiView /SYS/Utilities/More /C/TYPE );
-      unshift @pagers, "$ENV{PAGER}" if $ENV{PAGER}; 
+      unshift @pagers, "$ENV{PAGER}" if $ENV{PAGER};
     }
     else {
         if ($self->is_os2) {
@@ -1810,7 +1813,7 @@ sub containspod {
     local($_);
     my $fh = $self->open_fh("<", $file);
     while (<$fh>) {
-    if (/^=head/) {
+    if (/^=(head|pod)/) {
         close($fh)     or $self->die( "Can't close $file: $!" );
         return 1;
     }
@@ -1924,28 +1927,20 @@ sub page {  # apply a pager to the output file
         #  many many corners of the OS don't like it.  So we
         #  have to force it to be "\" to make everyone happy.
 
-	# if we are on an amiga convert unix path to an amiga one 
+	# if we are on an amiga convert unix path to an amiga one
 	$output =~ s/^\/(.*)\/(.*)/$1:$2/ if $self->is_amigaos;
 
         foreach my $pager (@pagers) {
             $self->aside("About to try calling $pager $output\n");
             if ($self->is_vms) {
                 last if system("$pager $output") == 0;
-	    } elsif($self->is_amigaos) { 
+	    } elsif($self->is_amigaos) {
                 last if system($pager, $output) == 0;
             } else {
-                if ( $self->{'formatter_class'} =~ /ToTerm/i ) {
-                  # fix visible escape codes in ToTerm output
-                  # https://bugs.debian.org/758689
-                  $self->aside("Possibly changing environment variables for less or more pagers\n");
-                  $ENV{LESS} = defined $ENV{LESS} ? $ENV{LESS} : "-R";
-                  # Don't mess with the environment for MORE on Windows or DOS
-                  if ( ! $self->is_mswin32 || ! $self->is_dos ) {
-                    # On FreeBSD, the default pager is more.
-                    $ENV{MORE} = defined $ENV{MORE} ? $ENV{MORE} : "-R";
-                  }
-                  $self->aside("less environment: " . $ENV{LESS} ."\n") if $ENV{LESS};
-                  $self->aside("more environment: " . $ENV{MORE} ."\n") if $ENV{MORE};
+                my $formatter = $self->{'formatter_class'};
+                if ( $formatter->can('pager_configuration') ) {
+                  $self->aside("About to call $formatter" . "->pager_configuration(\"$pager\")\n");
+                  $formatter->pager_configuration($pager, $self);
                 }
                 last if system("$pager \"$output\"") == 0;
             }
